import type { Cell } from './Cell.js';
import type { Edges } from './Edges.js';
import type { Directions } from './Directions.js';
/**
 * The representation of an edge of a cell
 */
export declare class Edge<TValue, TDirections extends Directions, TCell extends Cell<TValue, TDirections>> {
    protected edges: Edges<TValue, TDirections, TCell>;
    private getPreviousEdgeDirection;
    private getNextEdgeDirection;
    sourceCell: TCell;
    direction: TDirections['Edge'];
    neighborCell?: TCell | undefined;
    id: string;
    /**
     * @param edges The edges instance
     * @param getPreviousEdgeDirection
     * @param getNextEdgeDirection
     * @param sourceCell
     * @param direction
     * @param neighborCell
     */
    constructor(edges: Edges<TValue, TDirections, TCell>, getPreviousEdgeDirection: (direction: TDirections['Edge']) => TDirections['Edge'], getNextEdgeDirection: (direction: TDirections['Edge']) => TDirections['Edge'], sourceCell: TCell, direction: TDirections['Edge'], neighborCell?: TCell | undefined);
    /**
     * @returns The previous connected edge (e.g. for a square, the previous edge of "top" would be "left")
     * @protected
     */
    getPreviousEdge(): Edge<TValue, TDirections, TCell>;
    /**
     * @returns The next connected edge (e.g. for a square, the next edge of "top" would be "right")
     * @protected
     */
    getNextEdge(): Edge<TValue, TDirections, TCell>;
}
