import type { Grid } from './Grid.js';
import type { Cell } from './Cell.js';
import { type CellValueChangedEvent } from './utils/index.js';
import type { Directions } from './Directions.js';
/**
 * The row of a grid contains all information of the rows' cells
 */
export declare class Row<TValue, TDirections extends Directions, TCell extends Cell<TValue, TDirections>> {
    private grid;
    row: number;
    readonly id: string;
    private readonly _cells;
    private readonly eventDispatcher;
    /**
     * @param grid The grid this row is part of
     * @param row The row coordinate inside the grid
     */
    constructor(grid: Grid<TValue, TDirections, TCell>, row: number);
    /**
     * @returns all cells of this row
     */
    get cells(): TCell[];
    /**
     * @param col The column coordinate of the grid
     * @returns A cell
     */
    getCell(col: number): TCell;
    /**
     * @param callback A function that should be called, when a cell value of this row changes
     * @returns a function to unregister the callback
     */
    onCellValueChanged(callback: (event: CellValueChangedEvent<TValue, TDirections>) => void): () => void;
}
