import type { Cell } from '../Cell.js';
import type { Directions } from '../Directions.js';
/**
 * The event that will be created when the value of a cell was changed
 */
export type CellValueChangedEvent<TValue, TDirections extends Directions> = {
    /**
     * The cell which value has changed
     */
    cell: Cell<TValue, TDirections>;
};
/**
 * A class that implements this interface dispatches events about the grid
 */
export declare class GridEventDispatcher<Value, TDirections extends Directions> {
    cellValueChangedListeners: ((event: CellValueChangedEvent<Value, TDirections>) => void)[];
    /**
     * @param callback A function that should be called, when a cell value changes
     * @returns a function to unregister the callback
     */
    onCellValueChanged(callback: (event: CellValueChangedEvent<Value, TDirections>) => void): () => void;
    /**
     * @param event The event that should be dispatched to all registered callbacks
     */
    dispatchCellValueChangedEvent(event: CellValueChangedEvent<Value, TDirections>): void;
}
